pub struct TextureArray { /* private fields */ }Expand description
A collection of different textures with the same size.
If you want to use different images to render multiple sprites efficiently,
a TextureArray can do the job.
You need to use a Builder or a Loader to create one. Use a Batch
to draw it.
Cloning a TextureArray is cheap, it only clones a handle. It does not
create new copy of the texture on the GPU.