Event

Enum Event 

pub enum Event {
    CursorMoved {
        x: f32,
        y: f32,
    },
    CursorEntered,
    CursorLeft,
    CursorTaken,
    CursorReturned,
    Input {
        state: ButtonState,
        button: Button,
    },
    WheelScrolled {
        delta_x: f32,
        delta_y: f32,
    },
}
A mouse event.

Variants



CursorMoved

The mouse cursor was moved

Fields

x: f32

The X coordinate of the mouse position

y: f32

The Y coordinate of the mouse position



CursorEntered

The mouse cursor entered the game window.



CursorLeft

The mouse cursor left the game window.



CursorTaken

The mouse cursor has been taken and is in use.

This event is fired when the cursor is hovering or interacting with a UserInterface.



CursorReturned

The mouse cursor has been returned and is no longer in use.



Input

A mouse button was pressed or released.

Fields

state: ButtonState

The state of the button

button: Button

The button identifier



WheelScrolled

The mouse wheel was scrolled.

Fields

delta_x: f32

The number of horizontal lines scrolled

delta_y: f32

The number of vertical lines scrolled