pub trait Join {
type Type;
// Required method
fn join(self) -> Task<Self::Type>;
}Expand description
Join multiple tasks with ease.
Learn more about how to use this trait in the Task docs.
pub trait Join {
type Type;
// Required method
fn join(self) -> Task<Self::Type>;
}Join multiple tasks with ease.
Learn more about how to use this trait in the Task docs.