pub enum Event {
CursorMoved {
x: f32,
y: f32,
},
CursorEntered,
CursorLeft,
CursorTaken,
CursorReturned,
Input {
state: ButtonState,
button: Button,
},
WheelScrolled {
delta_x: f32,
delta_y: f32,
},
}Expand description
A mouse event.
Variants
CursorMoved
The mouse cursor was moved
CursorEntered
The mouse cursor entered the game window.
CursorLeft
The mouse cursor left the game window.
CursorTaken
The mouse cursor has been taken and is in use.
This event is fired when the cursor is hovering or interacting with a
UserInterface.
CursorReturned
The mouse cursor has been returned and is no longer in use.
Input
A mouse button was pressed or released.
WheelScrolled
The mouse wheel was scrolled.